searchData={"items":[{"type":"module","title":"Gridsquare","doc":"GridSquare calculator for encoding/decoding between latitude/longitude and\nMaidenhead Locator System grid references.\n\nThe Maidenhead Locator System is used by ham radio operators to exchange\napproximate locations. It uses a base conversion system with changing radix:\n- First pair: base 18 (A-R) for 10° lat × 20° lon fields\n- Second pair: base 10 (0-9) for 1° lat × 2° lon squares\n- Third pair: base 24 (A-X) for 2.5' lat × 5' lon subsquares\n- Fourth pair: base 10 (0-9) for extended subsquares\n- Can be extended indefinitely with alternating base 10/base 24 pairs","ref":"Gridsquare.html"},{"type":"type","title":"Gridsquare.base18_char/0","doc":"Base18 char (A-R)","ref":"Gridsquare.html#t:base18_char/0"},{"type":"type","title":"Gridsquare.base24_char/0","doc":"Base24 char (A-X)","ref":"Gridsquare.html#t:base24_char/0"},{"type":"type","title":"Gridsquare.coordinates/0","doc":"Internal coordinates for extended precision","ref":"Gridsquare.html#t:coordinates/0"},{"type":"function","title":"Gridsquare.decode/1","doc":"Decodes a grid square reference to latitude and longitude.","ref":"Gridsquare.html#decode/1"},{"type":"function","title":"Examples - Gridsquare.decode/1","doc":"iex> Gridsquare.decode(\"DN40bi\")\n    %Gridsquare.DecodeResult{latitude: 40.35416666666667, longitude: -111.875, width: 0.08333333333333333, height: 0.041666666666666664}","ref":"Gridsquare.html#decode/1-examples"},{"type":"type","title":"Gridsquare.decode_result/0","doc":"","ref":"Gridsquare.html#t:decode_result/0"},{"type":"function","title":"Gridsquare.encode/3","doc":"Encodes latitude and longitude to a grid square reference.","ref":"Gridsquare.html#encode/3"},{"type":"function","title":"Examples - Gridsquare.encode/3","doc":"iex> Gridsquare.encode(-111.866785, 40.363840)\n    %Gridsquare.EncodeResult{grid_reference: \"DN40bi\", subsquare: \"dn40bi\"}\n\n    iex> Gridsquare.encode(-111.866785, 40.363840, 10)\n    %Gridsquare.EncodeResult{grid_reference: \"DN40BI00OR\", subsquare: \"dn40bi\"}","ref":"Gridsquare.html#encode/3-examples"},{"type":"type","title":"Gridsquare.encode_result/0","doc":"","ref":"Gridsquare.html#t:encode_result/0"},{"type":"type","title":"Gridsquare.field_index/0","doc":"Field index (0-17)","ref":"Gridsquare.html#t:field_index/0"},{"type":"type","title":"Gridsquare.grid_height/0","doc":"Height of grid square in degrees","ref":"Gridsquare.html#t:grid_height/0"},{"type":"type","title":"Gridsquare.grid_reference/0","doc":"Maidenhead grid reference string (uppercase/lowercase, 6-20 chars)","ref":"Gridsquare.html#t:grid_reference/0"},{"type":"type","title":"Gridsquare.grid_square/0","doc":"","ref":"Gridsquare.html#t:grid_square/0"},{"type":"type","title":"Gridsquare.grid_width/0","doc":"Width of grid square in degrees","ref":"Gridsquare.html#t:grid_width/0"},{"type":"type","title":"Gridsquare.latitude/0","doc":"Latitude in degrees (-90.0 to 90.0)","ref":"Gridsquare.html#t:latitude/0"},{"type":"type","title":"Gridsquare.longitude/0","doc":"Longitude in degrees (-180.0 to 180.0)","ref":"Gridsquare.html#t:longitude/0"},{"type":"function","title":"Gridsquare.new/1","doc":"Creates a new GridSquare struct from a grid reference.","ref":"Gridsquare.html#new/1"},{"type":"function","title":"Examples - Gridsquare.new/1","doc":"iex> grid = Gridsquare.new(\"DN40bi\")\n    iex> grid.center\n    %{latitude: 40.35416666666667, longitude: -111.875}\n    iex> grid.width\n    0.08333333333333333\n    iex> grid.height\n    0.041666666666666664","ref":"Gridsquare.html#new/1-examples"},{"type":"type","title":"Gridsquare.normalized_latitude/0","doc":"Latitude normalized to -90.0 <= x < 90.0","ref":"Gridsquare.html#t:normalized_latitude/0"},{"type":"type","title":"Gridsquare.normalized_longitude/0","doc":"Longitude normalized to -180.0 <= x < 180.0","ref":"Gridsquare.html#t:normalized_longitude/0"},{"type":"type","title":"Gridsquare.precision/0","doc":"Precision (number of characters in grid reference, 6 to 20)","ref":"Gridsquare.html#t:precision/0"},{"type":"type","title":"Gridsquare.square_index/0","doc":"Square index (0-9)","ref":"Gridsquare.html#t:square_index/0"},{"type":"type","title":"Gridsquare.subsquare/0","doc":"Subsquare string (lowercase, 6 chars)","ref":"Gridsquare.html#t:subsquare/0"},{"type":"type","title":"Gridsquare.subsquare_index/0","doc":"Subsquare index (0-23)","ref":"Gridsquare.html#t:subsquare_index/0"},{"type":"module","title":"Gridsquare.DecodeResult","doc":"","ref":"Gridsquare.DecodeResult.html"},{"type":"type","title":"Gridsquare.DecodeResult.t/0","doc":"Result of decode/1","ref":"Gridsquare.DecodeResult.html#t:t/0"},{"type":"module","title":"Gridsquare.EncodeResult","doc":"","ref":"Gridsquare.EncodeResult.html"},{"type":"type","title":"Gridsquare.EncodeResult.t/0","doc":"Result of encode/3","ref":"Gridsquare.EncodeResult.html#t:t/0"},{"type":"module","title":"Gridsquare.GridSquare","doc":"","ref":"Gridsquare.GridSquare.html"},{"type":"type","title":"Gridsquare.GridSquare.t/0","doc":"GridSquare struct","ref":"Gridsquare.GridSquare.html#t:t/0"},{"type":"extras","title":"Gridsquare","doc":"# Gridsquare\n\n[![Hex.pm](https://img.shields.io/hexpm/v/gridsquare.svg)](https://hex.pm/packages/gridsquare)\n[![Hex.pm](https://img.shields.io/hexpm/dt/gridsquare.svg)](https://hex.pm/packages/gridsquare)\n[![Hex.pm](https://img.shields.io/hexpm/l/gridsquare.svg)](https://hex.pm/packages/gridsquare)\n[![CI](https://github.com/gmcintire/gridsquare/workflows/CI/badge.svg)](https://github.com/gmcintire/gridsquare/actions)\n\nGridSquare calculator for encoding/decoding between latitude/longitude and Maidenhead Locator System grid references.\n\nThe Maidenhead Locator System is used by ham radio operators to exchange approximate locations. It uses a base conversion system with changing radix:\n- First pair: base 18 (A-R) for 10° lat × 20° lon fields\n- Second pair: base 10 (0-9) for 1° lat × 2° lon squares\n- Third pair: base 24 (A-X) for 2.5' lat × 5' lon subsquares\n- Fourth pair: base 10 (0-9) for extended subsquares\n- Can be extended indefinitely with alternating base 10/base 24 pairs","ref":"readme.html"},{"type":"extras","title":"Installation - Gridsquare","doc":"The package can be installed by adding `gridsquare` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:gridsquare, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Gridsquare","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Encoding coordinates to grid square - Gridsquare","doc":"```elixir\n# Basic encoding (6-character precision)\nGridsquare.encode(-111.866785, 40.363840)\n# Returns: %Gridsquare.EncodeResult{grid_reference: \"DN40bi\", subsquare: \"dn40bi\"}\n\n# Extended precision (10-character precision)\nGridsquare.encode(-111.866785, 40.363840, 10)\n# Returns: %Gridsquare.EncodeResult{grid_reference: \"DN40BI00OR\", subsquare: \"dn40bi\"}\n```","ref":"readme.html#encoding-coordinates-to-grid-square"},{"type":"extras","title":"Decoding grid square to coordinates - Gridsquare","doc":"```elixir\nGridsquare.decode(\"DN40bi\")\n# Returns: %Gridsquare.DecodeResult{\n#   latitude: 40.35416666666667,\n#   longitude: -111.875,\n#   width: 0.08333333333333333,\n#   height: 0.041666666666666664\n# }\n```","ref":"readme.html#decoding-grid-square-to-coordinates"},{"type":"extras","title":"Creating a GridSquare struct - Gridsquare","doc":"```elixir\ngrid = Gridsquare.new(\"DN40bi\")\n# Returns: %Gridsquare.GridSquare{\n#   grid_reference: \"DN40bi\",\n#   center: %{latitude: 40.35416666666667, longitude: -111.875},\n#   width: 0.08333333333333333,\n#   height: 0.041666666666666664\n# }\n\n# Access the center coordinates\ngrid.center.latitude   # 40.35416666666667\ngrid.center.longitude  # -111.875\n\n# Access the dimensions\ngrid.width   # 0.08333333333333333 (5 minutes)\ngrid.height  # 0.041666666666666664 (2.5 minutes)\n```","ref":"readme.html#creating-a-gridsquare-struct"},{"type":"extras","title":"API Reference - Gridsquare","doc":"### `Gridsquare.encode(longitude, latitude, precision \\\\ 6)`\n\nEncodes latitude and longitude coordinates to a Maidenhead grid square reference.\n\n**Parameters:**\n- `longitude` (float): Longitude coordinate (-180 to 180)\n- `latitude` (float): Latitude coordinate (-90 to 90)\n- `precision` (integer): Number of characters in the grid reference (6 to 20, default: 6)\n\n**Returns:** `%Gridsquare.EncodeResult{grid_reference: String.t(), subsquare: String.t()}`\n\n### `Gridsquare.decode(grid_reference)`\n\nDecodes a Maidenhead grid square reference to latitude and longitude coordinates.\n\n**Parameters:**\n- `grid_reference` (String.t()): The grid square reference to decode\n\n**Returns:** `%Gridsquare.DecodeResult{latitude: float(), longitude: float(), width: float(), height: float()}`\n\n### `Gridsquare.new(grid_reference)`\n\nCreates a GridSquare struct from a grid reference.\n\n**Parameters:**\n- `grid_reference` (String.t()): The grid square reference\n\n**Returns:** `%Gridsquare.GridSquare{grid_reference: String.t(), center: %{latitude: float(), longitude: float()}, width: float(), height: float()}`","ref":"readme.html#api-reference"},{"type":"extras","title":"Precision Levels - Gridsquare","doc":"The precision parameter controls how many characters are in the resulting grid reference:\n\n- **6 characters** (default): Field + Square + Subsquare (2.5' × 5' precision)\n- **8 characters**: Adds first extended pair (base 10)\n- **10 characters**: Adds second extended pair (base 24)\n- **12 characters**: Adds third extended pair (base 10)\n- And so on...\n\nEach additional pair increases precision by approximately 10x.","ref":"readme.html#precision-levels"},{"type":"extras","title":"Examples - Gridsquare","doc":"```elixir\n# High precision encoding for precise location\nprecise_grid = Gridsquare.encode(-111.866785, 40.363840, 12)\n# %Gridsquare.EncodeResult{grid_reference: \"DN40BI00OR12\", subsquare: \"dn40bi\"}\n\n# Decode back to coordinates\nprecise_location = Gridsquare.decode(\"DN40BI00OR12\")\n# Returns %Gridsquare.DecodeResult{} with much higher precision\n```","ref":"readme.html#examples"},{"type":"extras","title":"Contributing - Gridsquare","doc":"1. Fork it\n2. Create your feature branch (`git checkout -b feature/my-new-feature`)\n3. Commit your changes (`git commit -am 'Add some feature'`)\n4. Push to the branch (`git push origin feature/my-new-feature`)\n5. Create new Pull Request","ref":"readme.html#contributing"},{"type":"extras","title":"License - Gridsquare","doc":"This project is licensed under the GPLv2 License - see the [LICENSE](LICENSE) file for details.","ref":"readme.html#license"},{"type":"extras","title":"Documentation - Gridsquare","doc":"Documentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc) and published on [HexDocs](https://hexdocs.pm). Once published, the docs can be found at  .","ref":"readme.html#documentation"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [Unreleased]\n\n## [0.1.0] - 2024-01-XX","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Initial release\n- `Gridsquare.encode/2` and `Gridsquare.encode/3` functions for encoding latitude/longitude to Maidenhead grid references\n- `Gridsquare.decode/1` function for decoding grid references to coordinates\n- `Gridsquare.new/1` function for creating GridSquare structs\n- Support for extended precision (6-20 characters)\n- Comprehensive documentation and examples\n- Test coverage for all functions","ref":"changelog.html#added"},{"type":"extras","title":"Features - Changelog","doc":"- Maidenhead Locator System grid square encoding/decoding\n- Variable precision support (6-20 character grid references)\n- Coordinate normalization and bounds checking\n- Base 18, 10, and 24 conversion utilities\n- Extended precision calculation with alternating base pairs","ref":"changelog.html#features"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}